Skip to contents

Call rfishbase::fb_tbl() to fetch data from FishBase and cache the result in cache_dir().

Usage

read_fb_tbl(tbl, ..., force = FALSE)

fb_species_ecology_estimate(..., force = FALSE)

Arguments

tbl, ...

Passed to rfishbase::fb_tbl().

force

Set to TRUE to ignore and overwrite existing cached files in cache_dir().

Value

A data frame.

fb_species_ecology_estimate() selects essential columns from "species", "ecology", and "estimate" tables.

Details

Note that some species have duplicated rows in ecology table, which is resolved in fb_species_ecology_estimate().

Examples

if (FALSE) { # \dontrun{
fb_species_ecology_estimate()

fb_species = read_fb_tbl("species")
fb_ecology = read_fb_tbl("ecology")
fb_estimate = read_fb_tbl("estimate")
} # }