directory_prefix() reads the ranemone.directory_prefix option set by users,
and is used for downloading and reading files.
It should be a persistent directory with easy access, such as ~/db,
not a temporary directory like tempdir().
directory_prefix() reads the ranemone.directory_prefix option set by users,
and is used for downloading and reading files.
It should be a persistent directory with easy access, such as ~/db,
not a temporary directory like tempdir().