ANEMONE DB contains a large collection of small tables, and this package provides efficient ways to read and process them. It may take a while to run them for the first time, but subsequent runs will be very quick because the results are cached.
Arguments
- filename
A filename to read. Files are searched recursively in the path returned by
directory_prefix(). It should be one of the following:community_qc3nn_target.tsv.xzcommunity_qc_target.tsv.xzcommunity_standard.tsv.xzexperiment.tsv.xzsample.tsv.xz
- compress
Compression method to use: "gz", "bz2", "xz" or "". If
NULL(default), the same one as the input file is used.- ...
Additional arguments passed to
readr::read_tsv().- limit
Maximum number of files to read at once.
- force
Set to
TRUEto ignore and overwrite existing files incache_dir().